@@ -1,5 +1,6 @@
-from functools import lru_cache
 
+from functools import lru_cache
+from simpledate.utils import always_tuple
 try:
     from _thread import allocate_lock as _thread_allocate_lock
 except ImportError:
@@ -13,7 +14,6 @@ from re import sub, escape, compile, IGNORECASE
 
 # extend the usual date parsing with:
 # - optional matching by adding a trailing ?
-# - space used to be \s+ to space? is \s*
 # - nestable grouping and alternatives as {A|B|C}
 #   use {} rather than () as less likely to appear in real text
 # - modify matchers for textual day, month, timezone that match any string
@@ -28,6 +28,13 @@ from re import sub, escape, compile, IGNORECASE
 
 
 def tokenizer(fmt):
+    '''
+    Split a format into a series of tokens.  For example,
+      {%H:!}?%M
+    will become
+      {, %H, :!, }, ?, %M
+    '''
+
     i = 0
     n = len(fmt)
 
@@ -49,7 +56,11 @@ def tokenizer(fmt):
         optional = j + 1 < n and fmt[j+1] == '?'
         if optional and fmt[i] != '}':
             yield '{'
+
+        # the token itself
         yield fmt[i:j+1]
+
+        # additional tokens to handle optional values as above
         if optional and fmt[i] != '}':
             yield '}'
         if optional:
@@ -60,6 +71,23 @@ def tokenizer(fmt):
 
 
 def _to_regexp(fmt, substitutions=None):
+    '''
+    Given a format, construct the equivalent regexp (and compile it) and
+    the information needed to reconstruct a matching template after use.
+
+    The reconstruction works by embedding empty matches in the regexp that
+    record which parts of the expression were matched.  For example, a
+    template like
+      {%H:!}?%M
+    is translated to
+      ((?P<G1>)(?P<H>2[0-3]|[0-1]\d|\d)[^\w]+)(?P<M>[0-5]\d|\d)
+    where the (?P<G1>) defines a group, named G1, that is defined only if
+    hours are matched.  The reconstruction dictionary looks like:
+      {'G0': '%G1%%M', 'G1': '%H:'}
+    and reconstruction starts with G0.  If G1 was matched, then %G1% is
+    substituted with the given reconstruction (and we repeat); if it was
+    not matched then %G1% is simply dropped.
+    '''
 
     if substitutions is None:
         substitutions = DEFAULT_SUBSTITUTIONS
@@ -127,6 +155,10 @@ def _to_regexp(fmt, substitutions=None):
 TAG = compile(r'(?:^|[^%])%(G\d+)%')
 
 def reconstruct(rebuild, found_dict):
+    '''
+    Implement the reconstruction described above, using the rebuild dictionary
+    and the group informatrion from a particular match.
+    '''
     fmt = rebuild['G0']
     while True:
         match = TAG.search(fmt)
@@ -161,6 +193,8 @@ WORD = lambda x: r'(?P<%s>(?:\w(?<=[^\d_]))+)' % x
 SYMBOL = r'[^\w]+'
 
 
+# these are the definitions used in the standard Python implementation
+
 BASE_SUBSTITUTIONS = {
     ' ': '\s+',
     '%a': seq_to_re(LOCALE_TIME.a_weekday, 'a'),
@@ -193,6 +227,9 @@ PYTHON_SUBSTITUTIONS.update({
     '%X': _to_regexp(LOCALE_TIME.LC_time, BASE_SUBSTITUTIONS)[0],
 })
 
+
+# extra definitions allowing more flexible matching.
+
 DEFAULT_SUBSTITUTIONS = dict(PYTHON_SUBSTITUTIONS)
 DEFAULT_SUBSTITUTIONS.update({
     ' !': r'[^\w]+',
@@ -210,6 +247,8 @@ DEFAULT_SUBSTITUTIONS.update({
 
 
 
+# thread-safe caching
+
 CACHE_MAX_SIZE = 100
 _CACHE_LOCK = _thread_allocate_lock()
 _CACHED_REGEXP = lru_cache(maxsize=CACHE_MAX_SIZE)(_to_regexp)
@@ -219,6 +258,9 @@ def to_regexp(fmt, substitutions=None):
         return _CACHED_REGEXP(fmt, substitutions)
 
 
+# the main logic to construct a date/time from the matched data, lifted
+# verbatim from the python source.  the only change is to check that
+# a group has actually matched (since now some may be optional).
 
 def to_time_tuple(found_dict):
     '''Closely based on _strptime in standard Python.'''
@@ -393,3 +435,38 @@ def strptime(data_string, format="%a %b %d %H:%M:%S %Y"):
     write_format = reconstruct(rebuild, found.groupdict())
 
     return date_time, fraction, write_format
+
+
+def _strip(fmt):
+    '''
+    Remove extensions from  a format, taking the first choice and including
+    optional parts.
+    '''
+    choice = [0]
+    for tok in tokenizer(fmt):
+        if len(tok) > 1 or tok == ' ':
+            if not any(choice):
+                if tok.endswith('!'):
+                    tok = tok[:-1]
+                yield tok
+        elif tok == '{':
+            choice.append(0)
+        elif tok == '|':
+            choice[-1] += 1
+        elif tok == '}':
+            choice.pop()
+        elif tok == '?':
+            pass
+        else:
+            yield tok
+
+
+def strip(fmt):
+    '''
+    Remove extensions from  a format, taking the first choice and including
+    optional parts.
+    '''
+    if not '{' in fmt and not '!' in fmt:
+        return fmt
+    else:
+        return ''.join(_strip(fmt))
